@@ -1,6 +1,6 @@
 /*
     SDL - Simple DirectMedia Layer
-    Copyright (C) 1997, 1998  Sam Lantinga
+    Copyright (C) 1997, 1998, 1999  Sam Lantinga
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -17,14 +17,12 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
     Sam Lantinga
-    5635-34 Springhouse Dr.
-    Pleasanton, CA 94588 (USA)
     slouken@devolution.com
 */
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_video.h,v 1.26 1999/07/15 18:42:02 slouken Exp $";
+ "@(#) $Id: SDL_video.h,v 1.5 1999/12/09 22:31:52 hercules Exp $";
 #endif
 
 /* Header file for access to the SDL raw framebuffer window */
@@ -39,6 +37,10 @@ static char rcsid =
 #include "SDL_rwops.h"
 
 #include "begin_code.h"
+/* Set up for C function definitions, even when using C++ */
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /* Useful data types */
 typedef struct {
@@ -118,7 +120,7 @@ typedef struct SDL_Surface {
 } SDL_Surface;
 
 /* These are the currently supported flags for the SDL_surface */
-/* Available for SDL_AllocSurface() or SDL_SetVideoMode() */
+/* Available for SDL_CreateRGBSurface() or SDL_SetVideoMode() */
 #define SDL_SWSURFACE	0x00000000	/* Surface is in system memory */
 #define SDL_HWSURFACE	0x00000001	/* Surface is in video memory */
 /* Available for SDL_SetVideoMode() */
@@ -133,6 +135,7 @@ typedef struct SDL_Surface {
 #define SDL_RLEACCEL	0x00004000	/* Colorkey blit is RLE accelerated */
 #define SDL_SRCALPHA	0x00010000	/* Blit uses source alpha blending */
 #define SDL_SRCCLIPPING	0x00100000	/* Blit uses source clipping */
+#define SDL_PREALLOC	0x01000000	/* Surface uses preallocated memory */
 
 /* Evaluates to true if the surface needs to be locked before access */
 #define SDL_MUSTLOCK(surface) \
@@ -174,18 +177,21 @@ typedef struct {
 	extern int  SDL_VideoInit(void);
 */
 
+/*
+ * This function returns a pointer to the current display surface.
+ * If SDL is doing format conversion on the display surface, this
+ * function returns the publicly visible surface, not the real video
+ * surface.
+ */
+extern DECLSPEC SDL_Surface * SDL_GetVideoSurface(void);
+
 /*
  * This function returns a read-only pointer to information about the
  * video hardware.  If this is called before SDL_SetVideoMode(), the 'vfmt'
  * member of the returned structure will contain the pixel format of the
  * "best" video mode.
  */
-SDL_DEFUN(const SDL_VideoInfo *, SDL_GetVideoInfo, (void))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_GetVideoInfo _SDL_GetVideoInfo
-#endif
-/**/
+extern DECLSPEC const SDL_VideoInfo * SDL_GetVideoInfo(void);
 
 /* 
  * Check to see if a particular video mode is supported.
@@ -198,11 +204,7 @@ SDL_DEFUN(const SDL_VideoInfo *, SDL_GetVideoInfo, (void))
  * The arguments to SDL_VideoModeOK() are the same ones you would pass to
  * SDL_SetVideoMode()
  */
-SDL_DEFUN(int, SDL_VideoModeOK, (int width, int height, int bpp, Uint32 flags))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_VideoModeOK _SDL_VideoModeOK
-#endif
+extern DECLSPEC int SDL_VideoModeOK(int width, int height, int bpp, Uint32 flags);
 
 /*
  * Return a pointer to an array of available screen dimensions for the
@@ -213,12 +215,7 @@ SDL_DEFUN(int, SDL_VideoModeOK, (int width, int height, int bpp, Uint32 flags))
  * If 'format' is NULL, the mode list will be for the format given 
  * by SDL_GetVideoInfo()->vfmt
  */
-SDL_DEFUN(SDL_Rect **, SDL_ListModes, (SDL_PixelFormat *format, Uint32 flags))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_ListModes _SDL_ListModes
-#endif
-/**/
+extern DECLSPEC SDL_Rect ** SDL_ListModes(SDL_PixelFormat *format, Uint32 flags);
 
 /*
  * Set up a video mode with the specified width, height and bits-per-pixel.
@@ -259,13 +256,8 @@ SDL_DEFUN(SDL_Rect **, SDL_ListModes, (SDL_PixelFormat *format, Uint32 flags))
  *
  * This function returns the video framebuffer surface, or NULL if it fails.
  */
-SDL_DEFUN(SDL_Surface *, SDL_SetVideoMode,
-			(int width, int height, int bpp, Uint32 flags))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_SetVideoMode _SDL_SetVideoMode
-#endif
-/**/
+extern DECLSPEC SDL_Surface *SDL_SetVideoMode
+			(int width, int height, int bpp, Uint32 flags);
 
 /*
  * Makes sure the given list of rectangles is updated on the given screen.
@@ -273,16 +265,10 @@ SDL_DEFUN(SDL_Surface *, SDL_SetVideoMode,
  * screen.
  * These functions should not be called while 'screen' is locked.
  */
-SDL_DEFUN(void, SDL_UpdateRects, 
-		(SDL_Surface *screen, int numrects, SDL_Rect *rects))
-SDL_DEFUN(void, SDL_UpdateRect, 
-		(SDL_Surface *screen, Sint32 x, Sint32 y, Uint32 w, Uint32 h))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_UpdateRects _SDL_UpdateRects
-# define SDL_UpdateRect _SDL_UpdateRect
-#endif
-/**/
+extern DECLSPEC void SDL_UpdateRects
+		(SDL_Surface *screen, int numrects, SDL_Rect *rects);
+extern DECLSPEC void SDL_UpdateRect
+		(SDL_Surface *screen, Sint32 x, Sint32 y, Uint32 w, Uint32 h);
 
 /*
  * On hardware that supports double-buffering, this function sets up a flip
@@ -294,12 +280,7 @@ SDL_DEFUN(void, SDL_UpdateRect,
  * setting the video mode for this function to perform hardware flipping.
  * This function returns 0 if successful, or -1 if there was an error.
  */
-SDL_DEFUN(int, SDL_Flip, (SDL_Surface *screen))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_Flip _SDL_Flip
-#endif
-/**/
+extern DECLSPEC int SDL_Flip(SDL_Surface *screen);
 
 /*
  * Sets a portion of the colormap for the given 8-bit surface.  If 'surface'
@@ -316,27 +297,23 @@ SDL_DEFUN(int, SDL_Flip, (SDL_Surface *screen))
  * you desire, even if the window colormap has to be warped or run under
  * emulation.
  */
-SDL_DEFUN(int, SDL_SetColors, (SDL_Surface *surface, 
-			SDL_Color *colors, int firstcolor, int ncolors))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_SetColors _SDL_SetColors
-#endif
-/**/
+extern DECLSPEC int SDL_SetColors(SDL_Surface *surface, 
+			SDL_Color *colors, int firstcolor, int ncolors);
 
 /*
  * Maps an RGB value to a 32-bit pixel for a given pixel format
  */
-SDL_DEFUN(Uint32, SDL_MapRGB,
-			(SDL_PixelFormat *format, Uint8 r, Uint8 g, Uint8 b))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_MapRGB _SDL_MapRGB
-#endif
-/**/
+extern DECLSPEC Uint32 SDL_MapRGB
+			(SDL_PixelFormat *format, Uint8 r, Uint8 g, Uint8 b);
 
 /*
- * Allocate and free a SDL surface (must be called after SDL_SetVideoMode)
+ * Maps a 32-bit pixel into the RGB components for a given pixel format
+ */
+extern DECLSPEC void SDL_GetRGB(Uint32 pixel,
+                         SDL_PixelFormat *fmt, Uint8 *r, Uint8 *g, Uint8 *b);
+
+/*
+ * Allocate and free an RGB surface (must be called after SDL_SetVideoMode)
  * If the depth is 4 or 8 bits, an empty palette is allocated for the surface.
  * If the depth is greater than 8 bits, the pixel format is set using the
  * flags '[RGB]mask'.
@@ -357,7 +334,7 @@ SDL_DEFUN(Uint32, SDL_MapRGB,
  * two surfaces in video memory, to place the surface in video memory
  * if possible, otherwise it will be placed in system memory.
  * SDL_SRCCOLORKEY and SDL_SRCALPHA will only be honored if the display 
- * surface is in video video memory (the surface returned by SDL_SetVideoMode()
+ * surface is in video memory (the surface returned by SDL_SetVideoMode()
  * has the SDL_HWSURFACE flag set.)
  * If the surface is created in video memory, blits will be _much_ faster,
  * but the surface format must be identical to the video surface format,
@@ -369,16 +346,14 @@ SDL_DEFUN(Uint32, SDL_MapRGB,
  * the SDL_HWSURFACE flag set, but will be created in system memory and 
  * returned anyway.
  */
-SDL_DEFUN(SDL_Surface *, SDL_AllocSurface,
+#define SDL_AllocSurface    SDL_CreateRGBSurface
+extern DECLSPEC SDL_Surface *SDL_CreateRGBSurface
 			(Uint32 flags, int width, int height, int depth, 
-			Uint32 Rmask, Uint32 Gmask, Uint32 Bmask, Uint32 Amask))
-SDL_DEFUN(void, SDL_FreeSurface, (SDL_Surface *surface))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_AllocSurface _SDL_AllocSurface
-# define SDL_FreeSurface _SDL_FreeSurface
-#endif
-/**/
+			Uint32 Rmask, Uint32 Gmask, Uint32 Bmask, Uint32 Amask);
+extern DECLSPEC SDL_Surface *SDL_CreateRGBSurfaceFrom(void *pixels,
+			int width, int height, int depth, int pitch,
+			Uint32 Rmask, Uint32 Gmask, Uint32 Bmask, Uint32 Amask);
+extern DECLSPEC void SDL_FreeSurface(SDL_Surface *surface);
 
 /*
  * SDL_LockSurface() sets up a surface for directly accessing the pixels.
@@ -398,14 +373,8 @@ SDL_DEFUN(void, SDL_FreeSurface, (SDL_Surface *surface))
  *
  * SDL_LockSurface() returns 0, or -1 if the surface couldn't be locked.
  */
-SDL_DEFUN(int, SDL_LockSurface, (SDL_Surface *surface))
-SDL_DEFUN(void, SDL_UnlockSurface, (SDL_Surface *surface))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_LockSurface _SDL_LockSurface
-# define SDL_UnlockSurface _SDL_UnlockSurface
-#endif
-/**/
+extern DECLSPEC int SDL_LockSurface(SDL_Surface *surface);
+extern DECLSPEC void SDL_UnlockSurface(SDL_Surface *surface);
 
 /*
  * Load a surface from a seekable SDL data source (memory or file.)
@@ -413,12 +382,8 @@ SDL_DEFUN(void, SDL_UnlockSurface, (SDL_Surface *surface))
  * Returns the new surface, or NULL if there was an error.
  * The new surface should be freed with SDL_FreeSurface().
  */
-SDL_DEFUN(SDL_Surface *, SDL_LoadBMP_RW, (SDL_RWops *src, int freesrc))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_LoadBMP_RW _SDL_LoadBMP_RW
-#endif
-/**/
+extern DECLSPEC SDL_Surface * SDL_LoadBMP_RW(SDL_RWops *src, int freesrc);
+
 /* Convenience macro -- load a surface from a file */
 #define SDL_LoadBMP(file)	SDL_LoadBMP_RW(SDL_RWFromFile(file, "rb"), 1)
 
@@ -427,13 +392,9 @@ SDL_DEFUN(SDL_Surface *, SDL_LoadBMP_RW, (SDL_RWops *src, int freesrc))
  * If 'freedst' is non-zero, the source will be closed after being written.
  * Returns 0 if successful or -1 if there was an error.
  */
-SDL_DEFUN(int, SDL_SaveBMP_RW,
-		(SDL_Surface *surface, SDL_RWops *dst, int freedst))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_SaveBMP_RW _SDL_SaveBMP_RW
-#endif
-/**/
+extern DECLSPEC int SDL_SaveBMP_RW
+		(SDL_Surface *surface, SDL_RWops *dst, int freedst);
+
 /* Convenience macro -- save a surface to a file */
 #define SDL_SaveBMP(surface, file) \
 		SDL_SaveBMP_RW(surface, SDL_RWFromFile(file, "wb"), 1)
@@ -445,13 +406,8 @@ SDL_DEFUN(int, SDL_SaveBMP_RW,
  * If 'flag' is 0, this function clears any current color key.
  * This function returns 0, or -1 if there was an error.
  */
-SDL_DEFUN(int, SDL_SetColorKey,
-			(SDL_Surface *surface, Uint32 flag, Uint32 key))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_SetColorKey _SDL_SetColorKey
-#endif
-/**/
+extern DECLSPEC int SDL_SetColorKey
+			(SDL_Surface *surface, Uint32 flag, Uint32 key);
 
 /*
  * If 'alpha' is non-zero, this function sets the alpha value for the 
@@ -472,12 +428,7 @@ SDL_DEFUN(int, SDL_SetColorKey,
  * The best use of this optimization is on surfaces that will be loaded
  * once and then be static most of the time they are in use.
  */
-SDL_DEFUN(int, SDL_SetAlpha, (SDL_Surface *surface, Uint32 flag, Uint8 alpha))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_SetAlpha _SDL_SetAlpha
-#endif
-/**/
+extern DECLSPEC int SDL_SetAlpha(SDL_Surface *surface, Uint32 flag, Uint8 alpha);
 
 /*
  * Sets the clipping rectangle for the source surface in a blit.
@@ -489,31 +440,21 @@ SDL_DEFUN(int, SDL_SetAlpha, (SDL_Surface *surface, Uint32 flag, Uint8 alpha))
  * Note that blits are automatically clipped to the edges of the source
  * and destination surfaces.
  */
-SDL_DEFUN(void, SDL_SetClipping, (SDL_Surface *surface,
-				int top, int left, int bottom, int right))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_SetClipping _SDL_SetClipping
-#endif
-/**/
+extern DECLSPEC void SDL_SetClipping(SDL_Surface *surface,
+				int top, int left, int bottom, int right);
 
 /*
  * Creates a new surface of the specified format, and then copies and maps 
  * the given surface to it so the blit of the converted surface will be as 
  * fast as possible.  If this function fails, it returns NULL.
  *
- * The 'flags' parameter is passed to SDL_AllocSurface() and has those 
+ * The 'flags' parameter is passed to SDL_CreateRGBSurface() and has those 
  * semantics.
  *
  * This function is used internally by SDL_DisplayFormat().
  */
-SDL_DEFUN(SDL_Surface *, SDL_ConvertSurface,
-			(SDL_Surface *src, SDL_PixelFormat *fmt, Uint32 flags))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_ConvertSurface _SDL_ConvertSurface
-#endif
-/**/
+extern DECLSPEC SDL_Surface *SDL_ConvertSurface
+			(SDL_Surface *src, SDL_PixelFormat *fmt, Uint32 flags);
 
 /*
  * This performs a fast blit from the source surface to the destination
@@ -546,21 +487,15 @@ SDL_DEFUN(SDL_Surface *, SDL_ConvertSurface,
 /* This is the public blit function, SDL_BlitSurface(), and it performs
    rectangle validation and clipping before passing it to SDL_LowerBlit()
 */
-SDL_DEFUN(int, SDL_UpperBlit,
+extern DECLSPEC int SDL_UpperBlit
 			(SDL_Surface *src, SDL_Rect *srcrect,
-			 SDL_Surface *dst, SDL_Rect *dstrect))
+			 SDL_Surface *dst, SDL_Rect *dstrect);
 /* This is a semi-private blit function and it performs low-level surface
    blitting only.
 */
-SDL_DEFUN(int, SDL_LowerBlit,
+extern DECLSPEC int SDL_LowerBlit
 			(SDL_Surface *src, SDL_Rect *srcrect,
-			 SDL_Surface *dst, SDL_Rect *dstrect))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_UpperBlit _SDL_UpperBlit
-# define SDL_LowerBlit _SDL_LowerBlit
-#endif
-/**/
+			 SDL_Surface *dst, SDL_Rect *dstrect);
 
 /*
  * This function performs a fast fill of the given rectangle with 'color'
@@ -569,13 +504,8 @@ SDL_DEFUN(int, SDL_LowerBlit,
  * can be generated by the SDL_MapRGB() function.
  * This function returns 0 on success, or -1 on error.
  */
-SDL_DEFUN(int, SDL_FillRect,
-		(SDL_Surface *dst, SDL_Rect *dstrect, Uint32 color))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_FillRect _SDL_FillRect
-#endif
-/**/
+extern DECLSPEC int SDL_FillRect
+		(SDL_Surface *dst, SDL_Rect *dstrect, Uint32 color);
 
 /* 
  * This function takes a surface and copies it to a new surface of the
@@ -588,12 +518,7 @@ SDL_DEFUN(int, SDL_FillRect,
  *
  * If the conversion fails or runs out of memory, it returns NULL
  */
-SDL_DEFUN(SDL_Surface *, SDL_DisplayFormat, (SDL_Surface *surface))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_DisplayFormat _SDL_DisplayFormat
-#endif
-/**/
+extern DECLSPEC SDL_Surface * SDL_DisplayFormat(SDL_Surface *surface);
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /* These functions allow interaction with the window manager, if any.        */
@@ -602,14 +527,8 @@ SDL_DEFUN(SDL_Surface *, SDL_DisplayFormat, (SDL_Surface *surface))
 /*
  * Sets/Gets the title and icon text of the display window
  */
-SDL_DEFUN(void, SDL_WM_SetCaption, (const char *title, const char *icon))
-SDL_DEFUN(void, SDL_WM_GetCaption, (char **title, char **icon))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_WM_SetCaption _SDL_WM_SetCaption
-# define SDL_WM_GetCaption _SDL_WM_GetCaption
-#endif
-/**/
+extern DECLSPEC void SDL_WM_SetCaption(const char *title, const char *icon);
+extern DECLSPEC void SDL_WM_GetCaption(char **title, char **icon);
 
 /*
  * Sets the icon for the display window.
@@ -617,13 +536,13 @@ SDL_DEFUN(void, SDL_WM_GetCaption, (char **title, char **icon))
  * It takes an icon surface, and a mask in MSB format.
  * If 'mask' is NULL, the entire icon surface will be used as the icon.
  */
-SDL_DEFUN(void, SDL_WM_SetIcon, (SDL_Surface *icon, Uint8 *mask))
-/**/
-#if defined(_SDL_DYNAMIC_LIB) && defined(_BUILDING_SDL)
-# define SDL_WM_SetIcon _SDL_WM_SetIcon
-#endif
-/**/
+extern DECLSPEC void SDL_WM_SetIcon(SDL_Surface *icon, Uint8 *mask);
 
+
+/* Ends C function definitions when using C++ */
+#ifdef __cplusplus
+};
+#endif
 #include "close_code.h"
 
 #endif /* _SDL_video_h */
