@@ -6,17 +6,12 @@
 #include <stdio.h>
 
 #include "SDL.h"
-#include "SDL_endian.h"
+#include "SDL_byteorder.h"
 
 main(int argc, char *argv[])
 {
 	SDL_version compiled;
 
-	/* Load from an alternate directory, if desired */
-	if ( argv[1] ) {
-		SDL_SetLibraryPath(argv[1]);
-	}
-
 	/* Initialize SDL */
 	if ( SDL_Init(0) < 0 ) {
 		fprintf(stderr, "Couldn't initialize SDL: %s\n",SDL_GetError());
